==> blender_2.63a.orig.tar.bz2: blender-2.63a/source/gameengine/GameLogic/SCA_RandomEventManager.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file SCA_RandomEventManager.h
 *  \ingroup gamelogic
 *  \brief Manager for random events
 */

#ifndef __SCA_RANDOMEVENTMANAGER_H__
#define __SCA_RANDOMEVENTMANAGER_H__

#include "SCA_EventManager.h"
#include <vector>

using namespace std;

class SCA_RandomEventManager : public SCA_EventManager
{
public:
	SCA_RandomEventManager(class SCA_LogicManager* logicmgr);

	virtual void NextFrame();


#ifdef WITH_CXX_GUARDEDALLOC
public:
	void *operator new(size_t num_bytes) { return MEM_mallocN(num_bytes, "GE:SCA_RandomEventManager"); }
	void operator delete( void *mem ) { MEM_freeN(mem); }
#endif
};

#endif //__SCA_RANDOMEVENTMANAGER_H__

==> blender_2.69.orig.tar.bz2: blender-2.69/source/gameengine/GameLogic/SCA_RandomEventManager.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file SCA_RandomEventManager.h
 *  \ingroup gamelogic
 *  \brief Manager for random events
 */

#ifndef __SCA_RANDOMEVENTMANAGER_H__
#define __SCA_RANDOMEVENTMANAGER_H__

#include "SCA_EventManager.h"
#include <vector>

using namespace std;

class SCA_RandomEventManager : public SCA_EventManager
{
public:
	SCA_RandomEventManager(class SCA_LogicManager* logicmgr);

	virtual void NextFrame();


#ifdef WITH_CXX_GUARDEDALLOC
	MEM_CXX_CLASS_ALLOC_FUNCS("GE:SCA_RandomEventManager")
#endif
};

#endif  /* __SCA_RANDOMEVENTMANAGER_H__ */
